@@ -1,9 +1,9 @@
 package App::ColorThemeUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-19'; # DATE
+our $DATE = '2021-01-20'; # DATE
 our $DIST = 'App-ColorThemeUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,6 +55,9 @@ $SPEC{show_color_theme_swatch} = {
             cmdline_aliases => {w=>{}},
         },
     },
+    links => [
+        {url=>'prog:show-colors-from-theme'},
+    ],
 };
 sub show_color_theme_swatch {
     require Color::ANSI::Util;
@@ -98,6 +101,28 @@ sub show_color_theme_swatch {
     [200];
 }
 
+$SPEC{list_color_theme_items} = {
+    v => 1.1,
+    args => {
+        theme => {
+            schema => 'perl::modname_with_optional_args*',
+            req => 1,
+            pos => 0,
+            cmdline_aliases => {m=>{}},
+        },
+    },
+};
+sub list_color_theme_items {
+    require Module::Load::Util;
+
+    my %args = @_;
+
+    my $theme = Module::Load::Util::instantiate_class_with_optional_args(
+        {ns_prefix=>'ColorTheme'}, $args{theme});
+    my @item_names = $theme->list_items;
+    [200, "OK", \@item_names];
+}
+
 1;
 # ABSTRACT: CLI utilities related to color themes
 
@@ -113,7 +138,7 @@ App::ColorThemeUtils - CLI utilities related to color themes
 
 =head1 VERSION
 
-This document describes version 0.009 of App::ColorThemeUtils (from Perl distribution App-ColorThemeUtils), released on 2020-06-19.
+This document describes version 0.010 of App::ColorThemeUtils (from Perl distribution App-ColorThemeUtils), released on 2021-01-20.
 
 =head1 DESCRIPTION
 
@@ -121,6 +146,8 @@ This distribution contains the following CLI utilities:
 
 =over
 
+=item * L<list-color-theme-items>
+
 =item * L<list-color-theme-modules>
 
 =item * L<show-color-theme-swatch>
@@ -130,6 +157,36 @@ This distribution contains the following CLI utilities:
 =head1 FUNCTIONS
 
 
+=head2 list_color_theme_items
+
+Usage:
+
+ list_color_theme_items(%args) -> [status, msg, payload, meta]
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<theme>* => I<perl::modname_with_optional_args>
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
 =head2 list_color_theme_modules
 
 Usage:
@@ -202,7 +259,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-ColorThemeUtils>
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ColorThemeUtils>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-ColorThemeUtils/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -218,7 +275,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
